summaryrefslogtreecommitdiff
path: root/src/python/gudhi/representations/preprocessing.py
diff options
context:
space:
mode:
authorVincent Rouvreau <vincent.rouvreau@inria.fr>2022-06-17 16:48:14 +0200
committerVincent Rouvreau <vincent.rouvreau@inria.fr>2022-06-17 16:48:14 +0200
commit3bfc066548fbdbd9b1dc06b39d8ccecd2ce4d0b5 (patch)
tree06c660c08bf83e4daf22039128b48572584812c5 /src/python/gudhi/representations/preprocessing.py
parentfc910c1bcb3451bcf3e288db25fecafe15cc42bb (diff)
doc review: tuple instead of pair - index is 'm' and not 'n'
Diffstat (limited to 'src/python/gudhi/representations/preprocessing.py')
-rw-r--r--src/python/gudhi/representations/preprocessing.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/python/gudhi/representations/preprocessing.py b/src/python/gudhi/representations/preprocessing.py
index bd8c2774..8722e162 100644
--- a/src/python/gudhi/representations/preprocessing.py
+++ b/src/python/gudhi/representations/preprocessing.py
@@ -402,12 +402,12 @@ class DimensionSelector(BaseEstimator, TransformerMixin):
Select persistence diagrams from its dimension.
Parameters:
X (list of list of pairs): List of list of persistence pairs, i.e.
`[[array( Hi(X0) ), array( Hj(X0) ), ...], [array( Hi(X1) ), array( Hj(X1) ), ...], ...]`
Returns:
- list of pairs:
- Persistence diagrams in a specific dimension. i.e. if `index` was set to `m` and `Hn` is at index `n` of
+ list of tuple:
+ Persistence diagrams in a specific dimension. i.e. if `index` was set to `m` and `Hn` is at index `m` of
the input, it returns `[array( Hn(X0) ), array( Hn(X1), ...]`
"""
@@ -402,12 +402,12 @@ class DimensionSelector(BaseEstimator, TransformerMixin):
Select persistence diagrams from its dimension.
Parameters:
- X (list of list of pairs): List of list of persistence pairs, i.e.
+ X (list of list of tuple): List of list of persistence pairs, i.e.
`[[array( Hi(X0) ), array( Hj(X0) ), ...], [array( Hi(X1) ), array( Hj(X1) ), ...], ...]`
Returns: